==> mir_2.20.2.orig.tar.xz: mir-2.20.2/README.md <==
# Mir - Wayland compositor

**Mir** is set of libraries for building Wayland based shells. Mir 
simplifies the complexity that shell authors need to deal with: it
provides a stable, well tested and performant platform with touch,
mouse and tablet input, multi-display capability and secure 
client-server communications.

Mir deals with the bringup and configuration of a broad array of
graphics and input hardware, abstracts hardware differences away
from shell authors (transparently dealing with hardware quirks) and
integrates with system components such as greeters.

Window management is integrated into Mir with useful default behaviour
and is extremely customisable by shell authors using a simple high-level
API.

## Resources
- For information on how to use Mir, refer to [the official documentation](https://canonical-mir.readthedocs-hosted.com).
- For data sheets and whitepapers, check out [the Mir website](http://mir-server.io).
- Mir is [hosted on GitHub](https://github.com/canonical/mir).
- For announcements and other discussions on Mir see [Ubuntu Discourse](https://discourse.ubuntu.com/c/mir) or join
[the matrix channel](https://matrix.to/#/#mir-server:matrix.org) to get in touch with the team.

## Copyright and License
Copyright © Canonical Ltd.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 or 3 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

==> mir_2.25.2.orig.tar.xz: mir-2.25.2/README.md <==
# Mir - Wayland compositor

**Mir** is set of libraries for building Wayland based shells. Mir
simplifies the complexity that shell authors need to deal with: it
provides a stable, well tested and performant platform with touch,
mouse and tablet input, multi-display capability and secure
client-server communications.

Mir deals with the bringup and configuration of a broad array of
graphics and input hardware, abstracts hardware differences away
from shell authors (transparently dealing with hardware quirks) and
integrates with system components such as greeters.

Window management is integrated into Mir with useful default behaviour
and is extremely customisable by shell authors using a simple high-level
API.

## Resources

- For information on how to use Mir, refer to [the official documentation](https://canonical-mir.readthedocs-hosted.com).
- For data sheets and whitepapers, check out [the Mir website](https://canonical.com/mir).
- Mir is [hosted on GitHub](https://github.com/canonical/mir).
- For announcements and other discussions on Mir see [Ubuntu Discourse](https://discourse.ubuntu.com/c/mir/15) or join
  [the matrix channel](https://matrix.to/#/#mir-server:matrix.org) to get in touch with the team.

## Packaging status

[![Packaging status](https://repology.org/badge/vertical-allrepos/mir.svg)](https://repology.org/project/mir/versions)

## Copyright and License

Copyright © Canonical Ltd.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 or 3 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
